@@ -161,7 +161,7 @@ def sequence_match(TIMIT_phoneme, ASR_phoneme):
   return phoneme_counter_dict
 
 #Using ASR model, convert .wav file into phn and iteratively replace the phn file of asr_dict
-def load_asr_dict(TIMIT_dict,asr_model, file_set = "TRAIN",DR = [0,7],noise_file = False):
+def load_asr_dict(TIMIT_dict,asr_model, file_set = "TRAIN",DR = [0,None],noise_file = False):
   ### <Purpose of function>: Using ASR model, convert .wav file into phn and iteratively replace the phn file of asr_dict
   ### <Input variables>:     TIMIT_dict = prior to this function, load the timit_file into a dictionary using the timit_load function in timit_load.py
   ###                        asr_model = function of ASR model, 
@@ -172,7 +172,7 @@ def load_asr_dict(TIMIT_dict,asr_model, file_set = "TRAIN",DR = [0,7],noise_file
   
   #create deepcopy of dictionary
   asr_dict = copy.deepcopy(TIMIT_dict)
-  for DR in list(asr_dict[file_set].keys())[DR[0]:DR[1]+1]:
+  for DR in list(asr_dict[file_set].keys())[DR[0]:DR[1]]:
     for speaker in tqdm(asr_dict[file_set][DR].keys()):
       timit_wav_list = asr_dict[file_set][DR][speaker]["wav"]
 
@@ -325,6 +325,7 @@ def compare_phn_wrd_noise(timit_wav,
                           timit_phn, 
                           timit_txt,
                           noise_wav,
+                          cfg_filedir,
                           asr_phn_model, 
                           asr_txt_model,
                           louder_volumes=[],
@@ -361,7 +362,7 @@ def compare_phn_wrd_noise(timit_wav,
 
   if len(louder_volumes) != 0 :
     for vol in louder_volumes:
-      add_noise(timit_wav,noise_wav,louder=vol) #add increasing noise & create new audio.wav
+      add_noise(timit_wav,noise_wav,cfg_filedir=cfg_filedir,louder=vol) #add increasing noise & create new audio.wav
       louder_path_dir = f"{timit_wav.split('.wav')[0]}_noise_louder{vol}dB.wav"
 
       #Phoneme ASR Model
@@ -379,7 +380,7 @@ def compare_phn_wrd_noise(timit_wav,
       os.remove(louder_path_dir)
   else:
     for vol in softer_volumes:
-      add_noise(timit_wav,noise_wav,softer=vol) #add decreasing noise & create new audio.wav
+      add_noise(timit_wav,noise_wav,cfg_filedir=cfg_filedir,softer=vol) #add decreasing noise & create new audio.wav
       softer_path_dir = f"{timit_wav.split('.wav')[0]}_noise_softer{vol}dB.wav"
 
       #Phoneme ASR Model     
@@ -404,6 +405,7 @@ def compare_phn_wrd_noise(timit_wav,
 
 def compare_phn_wrd_noise_multi(audio_dict,
                                 noise_wav,
+                                cfg_filedir,
                                 asr_phn_model,
                                 asr_txt_model,
                                 DR = [0,None],
@@ -436,6 +438,7 @@ def compare_phn_wrd_noise_multi(audio_dict,
                                            timit_phn = audio_dict[DR_index][speaker]['phn'][i], 
                                            timit_txt = audio_dict[DR_index][speaker]['txt'][i],
                                            noise_wav = noise_wav,
+                                           cfg_filedir=cfg_filedir,
                                            asr_phn_model = asr_phn_model, 
                                            asr_txt_model = asr_txt_model,
                                            louder_volumes= louder_volumes,
